searchNodes=[{"doc":"&quot;Mail merging&quot; with Ecto structs. A parser to interpolate MediaWiki-like [[foo.bar]] markup using data from Ecto schemas.","ref":"Mecto.html","title":"Mecto","type":"module"},{"doc":"Extracts nodes from some markup, returning a map where the end values are the count of how many times that node was in the markup. Note: this doesn't validate the nodes, just extracts them or errors if the markup is invalid. Examples iex&gt; Mecto . extract_nodes ( &quot;some text [[blog_post.title]] and [[blog_post.comments[0].content]]&quot; ) %{ blog_post : %{ title : 1 , comments : %{ 0 =&gt; %{ content : 1 } } } } iex&gt; Mecto . extract_nodes ( &quot;some text that [[is|invalid]]&quot; ) { :error , &quot;invalid markup&quot; }","ref":"Mecto.html#extract_nodes/1","title":"Mecto.extract_nodes/1","type":"function"},{"doc":"Interpolates markup with the values in the given Ecto structs. Note: this does not validate the markup (beyond checking it can be parsed) - it is expected that any text passed to this has already been validated with Mecto.validate/2 Examples iex&gt; Mecto . interpolate ( &quot;Title for post [[blog_post.title]]&quot; , % Mecto.BlogPost { title : &quot;some title&quot; } ) { :ok , &quot;Title for post some title&quot; } iex&gt; Mecto . interpolate ( &quot;Some [[[invalid markup]]&quot; , % Mecto.BlogPost { } ) { :error , &quot;invalid markup&quot; } iex&gt; Mecto . interpolate ( &quot;Some [[blog_post.invalid_field]]&quot; , % Mecto.BlogPost { } ) { :ok , &quot;Some &quot; }","ref":"Mecto.html#interpolate/2","title":"Mecto.interpolate/2","type":"function"},{"doc":"Builds a map from an Ecto schema, including following associations. Note: this will not recurse if a struct is repeated deeper in the tree. Examples iex&gt; Mecto . parse_schema ( Mecto.User ) %{ id : :id , username : :string } iex&gt; Mecto . parse_schema ( Mecto.Foo ) { :error , :missing_schema }","ref":"Mecto.html#parse_schema/1","title":"Mecto.parse_schema/1","type":"function"},{"doc":"Validates markup fields exist on the supplied schema. Examples iex&gt; Mecto . validate ( &quot;Title for post #[[blog_post.id]]&quot; , Mecto.BlogPost ) %{ blog_post : %{ id : :id } } iex&gt; Mecto . validate ( &quot;[[blog_post.invalid_field]]&quot; , Mecto.BlogPost ) { :error , [ &quot;blog_post.invalid_field does not exist&quot; ] }","ref":"Mecto.html#validate/2","title":"Mecto.validate/2","type":"function"},{"doc":"The protocol_ex protocol used to create schemas for custom Ecto types.","ref":"Mecto.CustomSchema.html","title":"Mecto.CustomSchema","type":"module"},{"doc":"","ref":"Mecto.CustomSchema.html#type/2","title":"Mecto.CustomSchema.type/2","type":"function"},{"doc":"Implementation of Mecto.CustomSchema for Ecto.Enum , using protocol_ex .","ref":"Mecto.CustomSchema.Ecto.Enum.html","title":"Mecto.CustomSchema.Ecto.Enum","type":"module"},{"doc":"","ref":"Mecto.CustomSchema.Ecto.Enum.html#type/2","title":"Mecto.CustomSchema.Ecto.Enum.type/2","type":"function"},{"doc":"Parses &quot;some text with [[tag.module]]&quot; into [tag: [:module]]","ref":"Mecto.MarkupParser.html","title":"Mecto.MarkupParser","type":"module"},{"doc":"","ref":"Mecto.MarkupParser.html#extract_nodes/1","title":"Mecto.MarkupParser.extract_nodes/1","type":"function"},{"doc":"Parses the given binary as parse. Returns {:ok, [token], rest, context, position, byte_offset} or {:error, reason, rest, context, line, byte_offset} where position describes the location of the parse (start position) as {line, offset_to_start_of_line} . To column where the error occurred can be inferred from byte_offset - offset_to_start_of_line . Options :byte_offset - the byte offset for the whole binary, defaults to 0 :line - the line and the byte offset into that line, defaults to {1, byte_offset} :context - the initial context value. It will be converted to a map","ref":"Mecto.MarkupParser.html#parse/2","title":"Mecto.MarkupParser.parse/2","type":"function"},{"doc":"Converts an Ecto schema into a map, for use in Mecto.SchemaValidator .","ref":"Mecto.SchemaExtractor.html","title":"Mecto.SchemaExtractor","type":"module"},{"doc":"","ref":"Mecto.SchemaExtractor.html#convert_from/1","title":"Mecto.SchemaExtractor.convert_from/1","type":"function"},{"doc":"Validates fields extracted with Mecto.MarkupParser exist based on the schema given from Mecto.MarkupParser .","ref":"Mecto.SchemaValidator.html","title":"Mecto.SchemaValidator","type":"module"},{"doc":"","ref":"Mecto.SchemaValidator.html#check/2","title":"Mecto.SchemaValidator.check/2","type":"function"},{"doc":"Used by Mecto.SchemaValidator to track the results of schema validation.","ref":"Mecto.SchemaValidator.Result.html","title":"Mecto.SchemaValidator.Result","type":"module"},{"doc":"","ref":"Mecto.SchemaValidator.Result.html#add_error/3","title":"Mecto.SchemaValidator.Result.add_error/3","type":"function"},{"doc":"","ref":"Mecto.SchemaValidator.Result.html#merge/3","title":"Mecto.SchemaValidator.Result.merge/3","type":"function"},{"doc":"Mecto &quot;Mail merging&quot; with Ecto structs. A parser to interpolate MediaWiki-like [[foo.bar]] markup using data from Ecto schemas.","ref":"readme.html","title":"README","type":"extras"},{"doc":"If available in Hex , the package can be installed by adding mecto to your list of dependencies in mix.exs : def deps do [ { :mecto , &quot;~&gt; 0.6.0&quot; } ] end","ref":"readme.html#installation","title":"README - Installation","type":"extras"},{"doc":"Mecto was originally built to provide dynamic &quot;mail-merging&quot; (think HEEx, but not compiled) from Elixir structs - specifically ones that use Ecto.Schema . Take this struct: defmodule MyApp.BlogPost do use Ecto.Schema schema &quot;blog_posts&quot; do field ( :title , :string ) field ( :content , :string ) end end You could then have some text like: text = &quot;The latest blog post is [[blog_post.title]]&quot; If you wanted to validate the text has correct markup, you could call: Mecto . validate ( text , MyApp.BlogPost ) &gt; %{ blog_post : %{ title : :string } } And Mecto would ensure that the fields used in the text actually exist on MyApp.BlogPost . You can also take it a step further, calling Mecto.interpolate to then use the values in a specific struct: Mecto . interpolate ( text , % MyApp.BlogPost { title : &quot;some title&quot; } ) &gt; { :ok , &quot;The latest blog post is some title&quot; } Mecto also handles relationships and custom Ecto types (i.e. defined with Ecto.Type ). By default there is an implementation for Ecto.Enum , but you can use protocol_ex for your own types. See the tests for more examples. Documentation can be found at https://hexdocs.pm/mecto .","ref":"readme.html#usage","title":"README - Usage","type":"extras"},{"doc":"If you want to support my work, you can donate on Liberapay:","ref":"readme.html#support-my-work","title":"README - Support my work","type":"extras"}]